@@ -6,13 +6,11 @@ extractCPT <- function(x, graph, smooth=0){
   if (!is.DAG(graph))
     stop("'graph' must be a DAG")
 
-  V   <- nodes(graph)
+  V   <- graph::nodes(graph)
   vpa <- vpar(graph)[V]
 
-  ##.vpa <<- vpa
-
   if (class(x)[1]=="data.frame"){
-      cat("extractCPT - data.frame\n")
+      ### cat("extractCPT - data.frame\n")
       ans <- lapply(vpa, function(ss){
           ##cat(sprintf("---- %s ----\n", toString( ss )))
           zzz <- xtabs(~., data=x[, ss, drop=FALSE])
@@ -28,10 +26,11 @@ extractCPT <- function(x, graph, smooth=0){
   chk <- unlist(lapply(ans, function(zz) any(is.na(zz))))
   nnn <- names(chk)[which(chk)]
   if (length(nnn)>0){
-      cat(sprintf("NA's found in conditional probability table(s) for nodes: %s\n", toString(nnn)))
-      cat(sprintf("  ... consider using the 'smooth' argument\n"))
+      cat(sprintf("NAs found in conditional probability table(s) for nodes: %s\n", toString(nnn)))
+      cat(sprintf("  ... consider using the smooth argument\n"))
   }
 
+  class(ans) <- c("extractCPT","list")
   ans
 }
 
@@ -53,26 +52,28 @@ extractPOT <- function(x, graph, smooth=0){
 
   attr(ans, "rip")     <- .rip
 
-  dg 	  <- .ug2dag(graph)
+  ## FIXME: Fix of ug2dag  ##dg 	  <- .ug2dag(graph)
+  dg 	    <- ug2dag(graph)
   cptlist <- extractCPT(x, dg, smooth=smooth)
   attr(ans, "dag")     <- dg        ## Needed to save network in Hugin format
   attr(ans, "cptlist") <- cptlist   ## Needed to save network in Hugin format
 
+  class(ans) <- c("extractPOT","list")
   ans
 }
 
 .extractPOT_table <- function(x, cliq, seps=NULL, smooth=0){
   ans <- vector("list", length(cliq))
-  for (ii in seq_along(cliq)){
-    cq    <- cliq[[ii]]
-    sp    <- seps[[ii]]
+  for ( i  in seq_along(cliq)){
+    cq    <- cliq[[ i ]]
+    sp    <- seps[[ i ]]
     t.cq  <- tableMargin(x, cq) + smooth
     names(dimnames(t.cq)) <- cq
     if (!is.null(seps) && length(sp)>0){
       t.sp      <- tableMargin(t.cq, sp)
-      ans[[ii]] <- tableOp2(t.cq, t.sp, op=`/`)
+      ans[[ i ]] <- tableOp2(t.cq, t.sp, op=`/`)
     } else {
-      ans[[ii]] <- t.cq / sum(t.cq)
+      ans[[ i ]] <- t.cq / sum(t.cq)
     }
   }
   ans
@@ -80,19 +81,40 @@ extractPOT <- function(x, graph, smooth=0){
 
 .extractPOT_dataframe <- function(x, cliq, seps=NULL, smooth=0){
   ans <- vector("list", length(cliq))
-  for (ii in seq_along(cliq)){
-    cq   <- cliq[[ii]]
-    sp   <- seps[[ii]]
+  for ( i  in seq_along(cliq)){
+    cq   <- cliq[[ i ]]
+    sp   <- seps[[ i ]]
+    ## FIXME: Would say that the following two lines do the same...
     xxx  <- xtabs(~., data=x[ , cq, drop=FALSE])
-    #xxx  <- as.table(ftable(x[ , cq, drop=FALSE]))
     t.cq <- tableMargin(xxx, cq) + smooth
     names(dimnames(t.cq)) <- cq
     if (!is.null(seps) && length(sp)>0){
-      t.sp      <- tableMargin(t.cq, sp)
-      ans[[ii]] <- tableOp2(t.cq, t.sp, op=`/`)
+      t.sp       <- tableMargin(t.cq, sp)
+      ans[[ i ]] <- tableOp2(t.cq, t.sp, op=`/`)
     } else {
-      ans[[ii]] <- t.cq / sum(t.cq)
+      ans[[ i ]] <- t.cq / sum(t.cq)
     }
   }
   ans
 }
+
+
+## FIXME: gRbase (1.7-2) now has ug2dag
+## FIXME: remove .ug2dag after in next release.
+#' .ug2dag <- function(ug){
+#'   m <- mcs(ug)
+#'   if (length(m)==0)
+#'     return(NULL)
+#'   adjList <- graph::adj(ug, m)
+#'   vparList <- vector("list",length(m))
+#'   names(vparList) <- m
+
+#'   ii <- 2
+#'   vparList[[1]] <- m[1]
+#'   for (ii in 2:length(m)){
+#'     vparList[[ii]] <- c(m[ii],intersectPrim(adjList[[ii]], m[1:ii]))
+#'   }
+
+#'   dg <- dagList(vparList)
+#'   dg
+#' }
